@@ -23,6 +23,9 @@ replace_url <- function(path){
     suffix <- regmatches(path, regexpr(pattern, path))
     path <- sub(pattern, "", path)
     paste0(download_url(path), suffix)
+  } else if(grepl("^[^/\\]+:$", path)) {
+    # demo images e.g. "logo:" or "wizard:"
+    return(path)
   } else {
     normalizePath(path, mustWork = FALSE)
   }
@@ -32,11 +35,10 @@ download_url <- function(url){
   req <- curl::curl_fetch_memory(url)
   if(req$status >= 400)
     stop(sprintf("Failed to download %s (HTTP %d)", url, req$status))
-  headers <- tolower(curl::parse_headers(req$headers))
-  ctype <- headers[grepl("^content.type", headers)]
-  ctype <- sub("content.type ?:? +", "", ctype)
+  headers <- curl::parse_headers_list(req$headers)
+  ctype <- headers[['content-type']]
   matches <- match(ctype, mimetypes$type)
-  extension <- if(length(matches) && !is.na(matches)){
+  extension <- if(length(matches) && !is.na(matches) && !grepl("(text|octet)", ctype)){
     sub("*.", ".", mimetypes$pattern[matches[1]], fixed = TRUE)
   } else {
     basename(url)
