@@ -97,6 +97,15 @@ XPtrImage magick_image_replace(XPtrImage image, Rcpp::IntegerVector index, XPtrI
   return image;
 }
 
+// [[Rcpp::export]]
+XPtrImage magick_image_copy(XPtrImage image, XPtrImage add){
+  image->resize(add->size());
+  for(size_t i = 0; i < add->size(); i++){
+    image->at(i) = add->at(i);
+  }
+  return image;
+}
+
 // [[Rcpp::export]]
 bool autobrewed(){
 #ifdef BUILD_AUTOBREW
