@@ -262,17 +262,6 @@ XPtrImage magick_image_trim( XPtrImage input){
   return output;
 }
 
-// [[Rcpp::export]]
-XPtrImage magick_image_composite( XPtrImage input, XPtrImage composite_image,
-                                  const char * offset, const char * composite){
-  XPtrImage output = copy(input);
-  if(composite_image->size()){
-    for_each(output->begin(), output->end(), Magick::compositeImage(composite_image->front(),
-      Geom(offset), Composite(composite)));
-  }
-  return output;
-}
-
 // [[Rcpp::export]]
 XPtrImage magick_image_contrast( XPtrImage input, size_t sharpen){
   XPtrImage output = copy(input);
